rai\_toolbox.mushin.BaseWorkflow
================================

.. currentmodule:: rai_toolbox.mushin

.. autoclass:: BaseWorkflow

   
   .. automethod:: __init__
   .. automethod:: task
   .. automethod:: jobs_post_process
   .. automethod:: run
   
   .. rubric:: Methods

   .. autosummary::
   
      ~BaseWorkflow.__init__
      ~BaseWorkflow.task
      ~BaseWorkflow.jobs_post_process
      ~BaseWorkflow.plot
      ~BaseWorkflow.run
      ~BaseWorkflow.to_xarray
      ~BaseWorkflow.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BaseWorkflow.cfgs
      ~BaseWorkflow.metrics
      ~BaseWorkflow.workflow_overrides
      ~BaseWorkflow.jobs
   
   